@@ -22,7 +22,7 @@ class ComponentReport:
             "License": "",
             "Popularity": "",
             "Recommended upgrade": "",
-            "Vulnerability List": "",
+            "Vulnerability List": [],
         }
 
     def set_field(self, key, value):
@@ -31,3 +31,9 @@ class ComponentReport:
             return 0
         else:
             return 1
+
+    def get_vul_list(self):
+        return self.info["Vulnerability List"]
+
+    def get_hash(self):
+        return self.info['Library'] + " " + self.info['Version']
\ No newline at end of file
