@@ -35,3 +35,6 @@ class IssueReport:
             return 0
         else:
             return 1
+
+    def get_hash(self):
+        return f"{self.info['Library']} {self.info['Library Version']} {self.info['Public ID']}"
